An example of two simple priors for forward market price to be used with powfutures130513
powpriors130513A data frame with 3885 rows and 3 columns:
vector of dates ranging from 2013-05-13 to final end date of contracts in powfutures130513
a simple smooth trigonometric prior describing power price seasonality
a trigonometric prior adjusted for typical calendar effects